"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const process_1 = tslib_1.__importDefault(require("process"));
const yargs_1 = tslib_1.__importDefault(require("yargs"));
const index_1 = require("../../index");
const { argv } = yargs_1.default
    .usage('$0 <directory> [options]', 'Clean TypeScript compilation products', {
    directory: {
        describe: 'Directory that contains source files',
        type: 'string'
    },
    dry: {
        alias: 'u',
        describe: 'List files without deletion',
        type: 'boolean',
        default: false
    },
    format: {
        alias: 'f',
        describe: 'Format of output to be printed to stdout',
        choices: ['text', 'json', 'none'],
        default: 'text'
    },
    jsonIndent: {
        describe: 'JSON indentation when --format=json',
        type: 'number',
        default: 2
    }
})
    .help();
const { directory, dry, format, jsonIndent } = argv;
main().then(status => process_1.default.exit(status), error => {
    console.error(error);
    process_1.default.exit(1);
});
async function main() {
    const { success, failure, targets, reports } = await (dry ? fakeClean : index_1.clean)(directory);
    if (format === 'text') {
        const list = (filelist) => filelist.forEach(filename => console.info(`  → ${filename}`));
        console.info('TypeScript Cleaner');
        console.info(`\nDetected ${targets.length} files to delete`);
        console.info(`\nDeleted ${success.length} files`);
        list(success);
        console.info(`\nFailed to delete ${failure.length} files`);
        list(failure);
        for (const { file, deletion } of reports) {
            if (deletion.success)
                continue;
            console.error(`\nFailed at ${file}`);
            console.error(deletion.error);
        }
    }
    else if (format === 'json') {
        const reasons = {};
        for (const { file, deletion } of reports) {
            if (!deletion.success) {
                reasons[file] = deletion.error;
            }
        }
        const text = JSON.stringify({ targets, success, failure, reasons }, undefined, jsonIndent);
        console.info(text);
    }
    return 0;
}
async function fakeClean(directory, options) {
    const targets = await index_1.listAllTargets(directory, options);
    const reports = targets.map(file => ({ file, deletion: { success: true } }));
    return { success: targets, failure: [], targets, reports };
}
//# sourceMappingURL=index.js.map